package paystation.domain;

public class PayStationImpl implements PayStation {
  private int insertedSoFar;
  
  /**
   * Insert coin into the pay station and adjust state accordingly.
   * @param coinValue is an integer value representing the coin in
   * cent. That is, a quarter is coinValue=25, etc.
   * @throws IllegalCoinException in case coinValue is not 
   * a valid coin value
   */
  public void addPayment( int coinValue ) throws IllegalCoinException {
    switch(coinValue) {
    case 5: break;
    case 25: break;
    default:
      throw new IllegalCoinException("Invalid coin: " + coinValue);
    }
    insertedSoFar = coinValue;
  }
  
  /**
   * Read the machine's display. The display shows a numerical
   * description of the amount of parking time accumulated so far
   * based on inserted payment.  
   * @return the number to display on the pay station display
   */
  public int readDisplay() {
    return insertedSoFar / 5 * 2;
  }

  /**
   * Buy parking time. Terminate the ongoing transaction and
   * return a parking receipt. A non-null object is always returned.
   * @return a valid parking receipt object.
   */ 
  public Receipt buy() {
    return null;
  }

  /**
   * Cancel the present transaction. Resets the machine for a new
   * transaction.
   */  
  public void cancel() {
  }
}

